from setuptools import setup, find_packages

setup(
    name='scgame',
    version='0.0.1',
    packages=find_packages(),
    license='Apache 2.0',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Bernie Huang',
    author_email='BernieHuang2008@163.com',
    url='https://github.com/BernieHuang2008/scgame',
    install_requires=[],
)